Omnibenchmark is being developed by the [Mark D. Robinson's lab](https://robinsonlabuzh.github.io/).

### About us

We are located in the [Department of Molecular Life Sciences](https://www.mls.uzh.ch/en.html) within the [Faculty of Science](https://www.mnf.uzh.ch/en.html) at the [University of Zurich](https://www.uzh.ch/cmsssl/en.html).

Research in our laboratory is focused on creating, comparing and understanding statistical methods and data science tools for processing and interpreting various types of genomic data. 

### Team

Almut Lütge, Anthony Sonrel, Charlotte Soneson, Daniel Incicau, Reto Gerber, Ben Carrillo, Izaskun Mallona, Mark D. Robinson

### Contact

- E-mail: mark.robinson (at) mls.uzh.ch
- Twitter: [@markrobinsonca](https://twitter.com/markrobinsonca) [@omnibenchmark](https://twitter.com/omnibenchmark)
- GitHub: [omnibenchmark](https://github.com/omnibenchmark)

**Address:**

```
Department of Molecular Life Sciences
University of Zurich
Winterthurerstrasse 190
CH-8057 Zurich, Switzerland

Office Y11-G-05
Phone  +41 44 635 48 48
Fax    +41 44 635 68 68
```
